# smcore

smcore provides base class agents and blackboard clients for use with [SimpleMind's go implementation](https://gitlab.com/sm-ai-team/sm-core-go).

This is still a work in progress and not yet ready for "primetime."  Functionality and API are likely to change until this message is removed.